@@ -7,7 +7,7 @@ my_username = u"fenton"
 
 monitored_channels = {} # "channel_name": time_i_last_chatted
 
-def generate_actions_from_irc_message(args):
+def generate_actions_from_irc_message(args,printer):
     # Generate a list of action based on input args.  The design of this
     # code is to run the generate_actions_from_irc_message method with a
     # give set of inputs: from_who, channel, message, and to_me?.  Based on
@@ -38,6 +38,9 @@ def generate_actions_from_irc_message(args):
         monitored_channels[channel] = time.time()
 
     monitoring_channel = monitored_channel( channel, monitored_channels )
+    if not to_me and not from_me and channel == "test":
+        printer("Monitoring channel" + channel, str(Monitoring_channel))
+
     if not to_me and not from_me and monitoring_channel:
         elapsed_time = get_elapsed_time_on_channel(channel, monitored_channels)
         alert_title, alrt_msg = construct_alert(from_who, channel, message, elapsed_time)
